@@ -239,26 +239,38 @@ gail_focus_watcher (GSignalInvocationHint *ihint,
                     }
                   widget = window->focus_widget;
                 }
-              else if (window->type == GTK_WINDOW_POPUP)
+              else if (window->type == GTK_WINDOW_POPUP) 
                 {
-                  GtkWidget *child = gtk_bin_get_child (GTK_BIN (widget));
+	          if (GTK_IS_BIN (widget))
+		    {
+		      GtkWidget *child = gtk_bin_get_child (GTK_BIN (widget));
 
-                  if (GTK_IS_WIDGET (child) && GTK_WIDGET_HAS_GRAB (child))
-                    {
-                      if (GTK_IS_MENU_SHELL (child))
-                        {
-                          if (GTK_MENU_SHELL (child)->active_menu_item)
-                            {
-                              /*
-                               * We have a menu which has a menu item selected
-                               * so we do not report focus on the menu.
-                               */ 
-                              return TRUE; 
-                            }
-                        }
-                      widget = child;
-                    } 
+		      if (GTK_IS_WIDGET (child) && GTK_WIDGET_HAS_GRAB (child))
+			{
+			  if (GTK_IS_MENU_SHELL (child))
+			    {
+			      if (GTK_MENU_SHELL (child)->active_menu_item)
+				{
+				  /*
+				   * We have a menu which has a menu item selected
+				   * so we do not report focus on the menu.
+				   */ 
+				  return TRUE; 
+				}
+			    }
+			  widget = child;
+			} 
+		    }
+		  else /* popup window has no children; this edge case occurs in some custom code (OOo for instance) */
+		    {
+		      return TRUE;
+		    }
                 }
+	      else /* Widget is a non-popup toplevel with no focus children; 
+		      don't emit for this case either, as it's useless */
+		{
+		  return TRUE;
+		}
             }
         }
       else
