@@ -451,15 +451,22 @@ state_event_watcher (GSignalInvocationHint  *hint,
     return TRUE;
   
   atk_obj = gtk_widget_get_accessible (widget);
-  g_return_val_if_fail (GAIL_IS_WINDOW (atk_obj), FALSE);
-  parent = atk_object_get_parent (atk_obj);
-  if (parent == atk_get_root ())
-    {
-      signal_id = g_signal_lookup (signal_name, GAIL_TYPE_WINDOW); 
-      g_signal_emit (atk_obj, signal_id, 0);
-    }
 
-  return TRUE;
+  if (GAIL_IS_WINDOW (atk_obj))
+    {
+      parent = atk_object_get_parent (atk_obj);
+      if (parent == atk_get_root ())
+	{
+	  signal_id = g_signal_lookup (signal_name, GAIL_TYPE_WINDOW); 
+	  g_signal_emit (atk_obj, signal_id, 0);
+	}
+      
+      return TRUE;
+    }
+  else
+    {
+      return FALSE;
+    }
 }
 
 static void
@@ -578,13 +585,19 @@ configure_event_watcher (GSignalInvocationHint  *hint,
     }
 
   atk_obj = gtk_widget_get_accessible (widget);
-  g_return_val_if_fail (GAIL_IS_WINDOW (atk_obj), FALSE);
-  parent = atk_object_get_parent (atk_obj);
-  if (parent == atk_get_root ())
+  if (GAIL_IS_WINDOW (atk_obj))
     {
-      signal_id = g_signal_lookup (signal_name, GAIL_TYPE_WINDOW); 
-      g_signal_emit (atk_obj, signal_id, 0);
+      parent = atk_object_get_parent (atk_obj);
+      if (parent == atk_get_root ())
+	{
+	  signal_id = g_signal_lookup (signal_name, GAIL_TYPE_WINDOW); 
+	  g_signal_emit (atk_obj, signal_id, 0);
+	}
+      
+      return TRUE;
+    }
+  else
+    {
+      return FALSE;
     }
-
-  return TRUE;
 }
